@@ -28,13 +28,21 @@
 #define __EOG_EXIF_UTIL_H__
 
 #include <glib.h>
+#include <glib-object.h>
 #include <libexif/exif-data.h>
 
 G_BEGIN_DECLS
 
+#define EOG_TYPE_EXIF_DATA eog_exif_data_get_type ()
+
 gchar*       eog_exif_util_format_date           (const gchar *date);
 
-const gchar *eog_exif_util_get_value             (ExifData *exif_data, gint tag_id, gchar *buffer, guint buf_size);
+const gchar *eog_exif_data_get_value             (ExifData *exif_data, gint tag_id, gchar *buffer, guint buf_size);
+
+GType                 eog_exif_data_get_type           (void) G_GNUC_CONST;
+
+ExifData * eog_exif_data_copy (ExifData *data);
+void          eog_exif_data_free (ExifData *data);
 
 G_END_DECLS
 
