@@ -7,7 +7,7 @@
  * Based on code by:
  * 	- Federico Mena-Quintero <federico@gnu.org>
  *	- Jens Finke <jens@gnome.org>
- * Based on evince code (shell/ev-window.c) by: 
+ * Based on evince code (shell/ev-window.c) by:
  * 	- Martin Kretzschmar <martink@gnome.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-G_BEGIN_DECLS 
+G_BEGIN_DECLS
 
 typedef struct _EogWindow EogWindow;
 typedef struct _EogWindowClass EogWindowClass;
@@ -57,6 +57,13 @@ typedef enum {
 	EOG_WINDOW_MODE_SLIDESHOW
 } EogWindowMode;
 
+typedef enum {
+	EOG_WINDOW_GALLERY_POS_BOTTOM,
+	EOG_WINDOW_GALLERY_POS_LEFT,
+	EOG_WINDOW_GALLERY_POS_TOP,
+	EOG_WINDOW_GALLERY_POS_RIGHT
+} EogWindowGalleryPos;
+
 //TODO
 typedef enum {
 	EOG_WINDOW_ERROR_CONTROL_NOT_FOUND,
@@ -71,7 +78,7 @@ typedef enum {
 typedef enum {
 	EOG_STARTUP_FULLSCREEN         = 1 << 0,
 	EOG_STARTUP_SLIDE_SHOW         = 1 << 1,
-	EOG_STARTUP_DISABLE_COLLECTION = 1 << 2
+	EOG_STARTUP_DISABLE_GALLERY    = 1 << 2
 } EogStartupFlags;
 
 struct _EogWindow {
@@ -111,11 +118,12 @@ GtkWidget    *eog_window_get_statusbar  (EogWindow       *window);
 
 EogImage     *eog_window_get_image      (EogWindow       *window);
 
-void          eog_window_open_file_list	(EogWindow       *window, 
+void          eog_window_open_file_list	(EogWindow       *window,
 					 GSList          *file_list);
 
 gboolean      eog_window_is_empty 	(EogWindow       *window);
 
+void          eog_window_reload_image (EogWindow *window);
 G_END_DECLS
 
 #endif
